# Qdata - Python SDK for index and search

* http://index.baidu.com/
* http://www.baidu.com/

### Install

```shell script
pip install qdata 
```

### Examples

#### 百度指数
`./examples/test_baidu_index.py`

#### 百度搜索
`./examples/test_baidu_search.py`


### Changelog

2021/03/25 待上线
